@@ -29,14 +29,14 @@ import menutreemodel
 import menufilewriter
 
 class MenuEditorDialog:
-    def __init__ (self):
+    def __init__ (self, menu_files):
         glade_file = os.path.join (GLADEDIR, "gmenu-simple-editor.glade")
         self.xml = gtk.glade.XML (glade_file, "menu_editor_dialog", PACKAGE)
 
         self.window = self.xml.get_widget ("menu_editor_dialog")
         self.window.connect ("destroy", gtk.main_quit)
         self.window.set_default_response (gtk.RESPONSE_ACCEPT)
-        self.window.set_icon_name ("gmenu-simple-editor")
+        self.window.set_icon_name ("gnome-main-menu")
 
         self.help_button = self.xml.get_widget ("help_button")
         self.help_button.set_sensitive (False)
@@ -44,7 +44,7 @@ class MenuEditorDialog:
         self.menus_tree   = self.xml.get_widget ("menus_treeview")
         self.entries_list = self.xml.get_widget ("applications_treeview")
 
-        self.menu_tree_model = menutreemodel.MenuTreeModel ()
+        self.menu_tree_model = menutreemodel.MenuTreeModel (menu_files)
         
         self.menu_file_writer = menufilewriter.MenuFileWriter (self.menu_tree_model)
 
